@@ -5,11 +5,12 @@ declare(strict_types=1);
 namespace LaminasTest\Stdlib;
 
 use Laminas\Stdlib\ArrayStack;
+use PHPUnit\Framework\Attributes\CoversClass;
 use PHPUnit\Framework\TestCase;
 
 use function iterator_to_array;
 
-/** @covers \Laminas\Stdlib\ArrayStack */
+#[CoversClass(ArrayStack::class)]
 final class ArrayStackTest extends TestCase
 {
     public function testIteration(): void
